@@ -68,13 +68,12 @@ def args_vs_config(args, config):
 
 
 def get_config(forge):
-    og = f"{Path(__file__).parent.parent}/config"
+    og = f"{Path(__file__).parent.parent.parent}/example.cfg"
     path = f"{os.path.expanduser('~/.gitforge.cfg')}"
 
-    if not os.path.exists(og):
-        raise FileNotFoundError(og)
-
     if not os.path.exists(path):
+        if not os.path.exists(og):
+            raise FileNotFoundError(og)
         logging.debug(f"Copying {og} to {path}...")
         copyfile(og, path)
 
@@ -163,7 +162,7 @@ def paginated_requests(url, headers, params, results=[]):
 def print_output(output):
     if output and type(output) is list:
         if re.match(".*JOB.*IN.*FROM", output[0]):
-            pager(re.split(f"{os.linesep}|\\n|\\r", "\n".join(output)))
+            pager(output)
         else:
             print("\n".join(output))
     elif output and type(output) is str:
